(function (Drupal, once) {
  'use strict';

  /*
   * Provide empty alt tags to decorative images
   * @see: https://www.w3.org/WAI/tutorials/images/decorative/
   * @see: https://www.w3.org/WAI/WCAG22/Techniques/html/H67
   */
  Drupal.behaviors.decor = {
    attach: function (context, settings) {
      // Select images within elements that have the target attributes
      const selectors = [
        '.js-decor', // Recommended
        '.js-decorative-image', // Legacy
        '[data-decor="img"]' // Optional
      ];

      const elements = context.querySelectorAll(selectors.join(','));

      // For each matched element, find all <img> tags inside it
      once('decor-image', elements).forEach(function (element) {
        const images = element.querySelectorAll('img');
        images.forEach(function (img) {
          img.classList.add('is-decor');
          img.setAttribute('alt', '');
          img.setAttribute('role', 'presentation');
          img.removeAttribute('title');
        });
      });
    }
  };
})(Drupal, once);